@@ -3,7 +3,7 @@ package App::Greple::stripe;
 use 5.024;
 use warnings;
 
-our $VERSION = "0.9901";
+our $VERSION = "0.9902";
 
 =encoding utf-8
 
@@ -17,7 +17,7 @@ App::Greple::stripe - Greple zebra stripe module
 
 =head1 VERSION
 
-Version 0.9901
+Version 0.9902
 
 =head1 DESCRIPTION
 
@@ -148,12 +148,12 @@ sub opt :lvalue { ${$opt{+shift}} }
 
 sub hash_to_spec {
     pairmap {
-	$a = "$a|${\(uc(substr($a, 0, 1)))}";
+	my $key = "$a|${\(uc(substr($a, 0, 1)))}";
 	my $ref = ref $b;
-	if    (not defined $b)   { "$a!"  }
-	elsif ($ref eq 'SCALAR') { "$a!"  }
-	elsif (is_number($b))    { "$a=f" }
-	else                     { "$a=s" }
+	if    (not defined $b)   { "$key!"  }
+	elsif ($ref eq 'SCALAR') { "$key!"  }
+	elsif (is_number($b))    { "$key=f" }
+	else                     { "$key=s" }
     } shift->%*;
 }
 
@@ -208,7 +208,7 @@ sub finalize {
 	}
     }
     local $" = ',';
-    $mod->setopt(default => join(' ', @default, "--cm=@cm"));
+    $mod->setopt(default => join(' ', @default, '--cm=@', "--cm=@cm"));
 }
 
 #
